@@ -215,12 +215,34 @@ void Parrot_pcc_fill_params_from_varargs(PARROT_INTERP,
         FUNC_MODIFIES(*call_object)
         FUNC_MODIFIES(*args);
 
-void Parrot_pcc_merge_signature_for_tailcall(PARROT_INTERP,
-    ARGMOD_NULLOK(PMC * parent),
-    ARGMOD_NULLOK(PMC * tailcall))
+PARROT_EXPORT
+void Parrot_pcc_set_call_from_c_args(PARROT_INTERP,
+    ARGIN(PMC *signature),
+    ARGIN(const char *sig),
+    ...)
         __attribute__nonnull__(1)
-        FUNC_MODIFIES(* parent)
-        FUNC_MODIFIES(* tailcall);
+        __attribute__nonnull__(2)
+        __attribute__nonnull__(3);
+
+PARROT_EXPORT
+void Parrot_pcc_set_call_from_varargs(PARROT_INTERP,
+    ARGIN(PMC *signature),
+    ARGIN(const char *sig),
+    ARGMOD(va_list *args))
+        __attribute__nonnull__(1)
+        __attribute__nonnull__(2)
+        __attribute__nonnull__(3)
+        __attribute__nonnull__(4)
+        FUNC_MODIFIES(*args);
+
+void Parrot_pcc_merge_signature_for_tailcall(PARROT_INTERP,
+    ARGMOD(PMC *parent),
+    ARGMOD(PMC *tailcall))
+        __attribute__nonnull__(1)
+        __attribute__nonnull__(2)
+        __attribute__nonnull__(3)
+        FUNC_MODIFIES(*parent)
+        FUNC_MODIFIES(*tailcall);
 
 PARROT_CAN_RETURN_NULL
 void Parrot_pcc_parse_signature_string(PARROT_INTERP,
@@ -277,9 +299,22 @@ void Parrot_pcc_split_signature_string(
        PARROT_ASSERT_ARG(interp) \
     , PARROT_ASSERT_ARG(signature) \
     , PARROT_ASSERT_ARG(args))
+#define ASSERT_ARGS_Parrot_pcc_set_call_from_c_args \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(interp) \
+    , PARROT_ASSERT_ARG(signature) \
+    , PARROT_ASSERT_ARG(sig))
+#define ASSERT_ARGS_Parrot_pcc_set_call_from_varargs \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(interp) \
+    , PARROT_ASSERT_ARG(signature) \
+    , PARROT_ASSERT_ARG(sig) \
+    , PARROT_ASSERT_ARG(args))
 #define ASSERT_ARGS_Parrot_pcc_merge_signature_for_tailcall \
      __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
-       PARROT_ASSERT_ARG(interp))
+       PARROT_ASSERT_ARG(interp) \
+    , PARROT_ASSERT_ARG(parent) \
+    , PARROT_ASSERT_ARG(tailcall))
 #define ASSERT_ARGS_Parrot_pcc_parse_signature_string \
      __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
@@ -344,18 +379,18 @@ PMC ** Parrot_pcc_get_PMC_reg(PARROT_INTERP, ARGIN(PMC *ctx), UINTVAL idx)
 PARROT_EXPORT
 PARROT_PURE_FUNCTION
 PARROT_CANNOT_RETURN_NULL
-Regs_ni* Parrot_pcc_get_regs_ni(SHIM_INTERP, ARGIN(const PMC *ctx))
+Regs_ni* Parrot_pcc_get_regs_ni(PARROT_INTERP, ARGIN(const PMC *ctx))
         __attribute__nonnull__(2);
 
 PARROT_EXPORT
 PARROT_PURE_FUNCTION
 PARROT_CANNOT_RETURN_NULL
-Regs_ps* Parrot_pcc_get_regs_ps(SHIM_INTERP, ARGIN(PMC *ctx))
+Regs_ps* Parrot_pcc_get_regs_ps(PARROT_INTERP, ARGIN(PMC *ctx))
         __attribute__nonnull__(2);
 
 PARROT_EXPORT
 PARROT_PURE_FUNCTION
-UINTVAL Parrot_pcc_get_regs_used(SHIM_INTERP,
+UINTVAL Parrot_pcc_get_regs_used(PARROT_INTERP,
     ARGIN(const PMC *ctx),
     int type)
         __attribute__nonnull__(2);
@@ -372,7 +407,7 @@ STRING ** Parrot_pcc_get_STRING_reg(PARROT_INTERP,
 PARROT_EXPORT
 PARROT_PURE_FUNCTION
 PARROT_CAN_RETURN_NULL
-PMC* Parrot_pcc_get_sub(SHIM_INTERP, ARGIN(const PMC *ctx))
+PMC* Parrot_pcc_get_sub(PARROT_INTERP, ARGIN(const PMC *ctx))
         __attribute__nonnull__(2);
 
 PARROT_EXPORT
@@ -382,7 +417,7 @@ void Parrot_pcc_set_context_func(PARROT_INTERP, ARGIN(PMC *ctx))
 
 PARROT_EXPORT
 PARROT_CANNOT_RETURN_NULL
-void Parrot_pcc_set_regs_ni(SHIM_INTERP,
+void Parrot_pcc_set_regs_ni(PARROT_INTERP,
     ARGIN(PMC *ctx),
     ARGIN(Regs_ni *bp))
         __attribute__nonnull__(2)
@@ -390,14 +425,14 @@ void Parrot_pcc_set_regs_ni(SHIM_INTERP,
 
 PARROT_EXPORT
 PARROT_CANNOT_RETURN_NULL
-void Parrot_pcc_set_regs_ps(SHIM_INTERP,
+void Parrot_pcc_set_regs_ps(PARROT_INTERP,
     ARGIN(PMC *ctx),
     ARGIN(Regs_ps *bp_ps))
         __attribute__nonnull__(2)
         __attribute__nonnull__(3);
 
 PARROT_EXPORT
-void Parrot_pcc_set_regs_used(SHIM_INTERP,
+void Parrot_pcc_set_regs_used(PARROT_INTERP,
     ARGIN(PMC *ctx),
     int type,
     INTVAL num)
@@ -450,7 +485,7 @@ void Parrot_pcc_free_registers(PARROT_INTERP, ARGIN(PMC *pmcctx))
         __attribute__nonnull__(2);
 
 PARROT_CANNOT_RETURN_NULL
-PMC * Parrot_pcc_init_context(SHIM_INTERP,
+PMC * Parrot_pcc_init_context(PARROT_INTERP,
     ARGIN(PMC *ctx),
     ARGIN_NULLOK(PMC *old))
         __attribute__nonnull__(2);
